gskChat - gui
Description: A conversational AI system that listens, learns, and challenges

#

## Выбери своего бота

### Лучший программист

┕ Ответит на любой вопрос касательно программирования, а так же может написать любой код

### Лучший учитель

┕ Знает всё на свете. Хочешь научиться чему-то? Не знаешь чего-то? Тебе сюда

### Писатель

┕ Лучший философ. Нужен текст для лекции? Написать Хочешь придумать стих? тебе сюда
Сменить бота
АВТОРЫ

- @tafik23 - Фалюшин А.С (Программист)
- @fppzlxlac - Суслова А.С (Дизайнер)
- @Daniag0 - Малинин Д.Д (Контент)

×
Доступ к Паутине
Выключить историю чата